Instrument

Trait Instrument 

pub trait Instrument {
    // Required methods
    fn on_call_rejected(&self);
    fn on_open(&self);
    fn on_half_open(&self);
    fn on_closed(&self);
}
Consumes the state machine events. May used for metrics and/or logs.

Required Methods

fn on_call_rejected(&self)

Calls when state machine reject a call.

fn on_open(&self)

Calls when the circuit breaker become to open state.

fn on_half_open(&self)

Calls when the circuit breaker become to half open state.

fn on_closed(&self)

Calls when the circuit breaker become to closed state.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Instrument for ()

An instrumentation which does noting.

Implementors